import re
from dosage.modules.helpers.BasicComicModule import BasicComicModule

class VGCats(BasicComicModule):
    latestUrl = 'http://www.vgcats.com/comics/'
    imageUrl = 'http://www.vgcats.com/comics/?strip_id=%s'
    imageSearch = re.compile(r'<img src="(images/\d{6}\..+?)"', re.IGNORECASE)
    prevSearch = re.compile(r'<a href="(\?strip_id=\d+)"><img src="back.gif" border="0"')
    help = 'Index format: n (unpadded)'
